@@ -38,7 +38,10 @@ class Base():
         else:
             py_object = str(cls).replace('<class ', '')
             py_object.replace('>', '')
+            data = json.JSONDecoder().decode(data)
             data['py/object'] = py_object
+            data = json.JSONEncoder().encode(data)
+            
             class_object = jsonpickle.decode(data)
 
         if isinstance(class_object, cls):
